@@ -466,7 +466,6 @@
 #define SYS_acct __NR_acct
 #define SYS_acl_get __NR_acl_get
 #define SYS_acl_set __NR_acl_set
-#define SYS_add_key __NR_add_key
 #define SYS_adjtimex __NR_adjtimex
 #define SYS_afs_syscall __NR_afs_syscall
 #define SYS_alarm __NR_alarm
@@ -495,19 +494,14 @@
 #define SYS_dup2 __NR_dup2
 #define SYS_epoll_create __NR_epoll_create
 #define SYS_epoll_ctl __NR_epoll_ctl
-#define SYS_epoll_pwait __NR_epoll_pwait
 #define SYS_epoll_wait __NR_epoll_wait
-#define SYS_eventfd __NR_eventfd
 #define SYS_execve __NR_execve
 #define SYS_exit __NR_exit
 #define SYS_exit_group __NR_exit_group
-#define SYS_faccessat __NR_faccessat
 #define SYS_fadvise64_64 __NR_fadvise64_64
 #define SYS_fchdir __NR_fchdir
 #define SYS_fchmod __NR_fchmod
-#define SYS_fchmodat __NR_fchmodat
 #define SYS_fchown __NR_fchown
-#define SYS_fchownat __NR_fchownat
 #define SYS_fcntl __NR_fcntl
 #define SYS_fcntl64 __NR_fcntl64
 #define SYS_fdatasync __NR_fdatasync
@@ -520,19 +514,14 @@
 #define SYS_fsetxattr __NR_fsetxattr
 #define SYS_fstat __NR_fstat
 #define SYS_fstat64 __NR_fstat64
-#define SYS_fstatat64 __NR_fstatat64
 #define SYS_fstatfs __NR_fstatfs
-#define SYS_fstatfs64 __NR_fstatfs64
 #define SYS_fsync __NR_fsync
 #define SYS_ftruncate __NR_ftruncate
 #define SYS_ftruncate64 __NR_ftruncate64
 #define SYS_futex __NR_futex
-#define SYS_futimesat __NR_futimesat
 #define SYS_get_kernel_syms __NR_get_kernel_syms
 #define SYS_get_mempolicy __NR_get_mempolicy
-#define SYS_get_robust_list __NR_get_robust_list
 #define SYS_get_thread_area __NR_get_thread_area
-#define SYS_getcpu __NR_getcpu
 #define SYS_getcwd __NR_getcwd
 #define SYS_getdents __NR_getdents
 #define SYS_getdents64 __NR_getdents64
@@ -560,24 +549,16 @@
 #define SYS_getuid __NR_getuid
 #define SYS_getxattr __NR_getxattr
 #define SYS_init_module __NR_init_module
-#define SYS_inotify_add_watch __NR_inotify_add_watch
-#define SYS_inotify_init __NR_inotify_init
-#define SYS_inotify_rm_watch __NR_inotify_rm_watch
 #define SYS_io_cancel __NR_io_cancel
 #define SYS_io_destroy __NR_io_destroy
 #define SYS_io_getevents __NR_io_getevents
 #define SYS_io_setup __NR_io_setup
 #define SYS_io_submit __NR_io_submit
 #define SYS_ioctl __NR_ioctl
-#define SYS_ioprio_get __NR_ioprio_get
-#define SYS_ioprio_set __NR_ioprio_set
-#define SYS_kexec_load __NR_kexec_load
-#define SYS_keyctl __NR_keyctl
 #define SYS_kill __NR_kill
 #define SYS_lchown __NR_lchown
 #define SYS_lgetxattr __NR_lgetxattr
 #define SYS_link __NR_link
-#define SYS_linkat __NR_linkat
 #define SYS_listen __NR_listen
 #define SYS_listxattr __NR_listxattr
 #define SYS_llistxattr __NR_llistxattr
@@ -589,18 +570,14 @@
 #define SYS_lstat64 __NR_lstat64
 #define SYS_madvise __NR_madvise
 #define SYS_mbind __NR_mbind
-#define SYS_migrate_pages __NR_migrate_pages
 #define SYS_mincore __NR_mincore
 #define SYS_mkdir __NR_mkdir
-#define SYS_mkdirat __NR_mkdirat
 #define SYS_mknod __NR_mknod
-#define SYS_mknodat __NR_mknodat
 #define SYS_mlock __NR_mlock
 #define SYS_mlockall __NR_mlockall
 #define SYS_mmap __NR_mmap
 #define SYS_mmap2 __NR_mmap2
 #define SYS_mount __NR_mount
-#define SYS_move_pages __NR_move_pages
 #define SYS_mprotect __NR_mprotect
 #define SYS_mq_getsetattr __NR_mq_getsetattr
 #define SYS_mq_notify __NR_mq_notify
@@ -621,16 +598,13 @@
 #define SYS_nfsservctl __NR_nfsservctl
 #define SYS_nice __NR_nice
 #define SYS_open __NR_open
-#define SYS_openat __NR_openat
 #define SYS_pause __NR_pause
 #define SYS_personality __NR_personality
 #define SYS_pipe __NR_pipe
 #define SYS_pivot_root __NR_pivot_root
 #define SYS_poll __NR_poll
-#define SYS_ppoll __NR_ppoll
 #define SYS_prctl __NR_prctl
 #define SYS_pread64 __NR_pread64
-#define SYS_pselect6 __NR_pselect6
 #define SYS_ptrace __NR_ptrace
 #define SYS_putpmsg __NR_putpmsg
 #define SYS_pwrite64 __NR_pwrite64
@@ -639,7 +613,6 @@
 #define SYS_read __NR_read
 #define SYS_readahead __NR_readahead
 #define SYS_readlink __NR_readlink
-#define SYS_readlinkat __NR_readlinkat
 #define SYS_readv __NR_readv
 #define SYS_reboot __NR_reboot
 #define SYS_recv __NR_recv
@@ -648,8 +621,6 @@
 #define SYS_remap_file_pages __NR_remap_file_pages
 #define SYS_removexattr __NR_removexattr
 #define SYS_rename __NR_rename
-#define SYS_renameat __NR_renameat
-#define SYS_request_key __NR_request_key
 #define SYS_restart_syscall __NR_restart_syscall
 #define SYS_rmdir __NR_rmdir
 #define SYS_rt_sigaction __NR_rt_sigaction
@@ -679,7 +650,6 @@
 #define SYS_sendmsg __NR_sendmsg
 #define SYS_sendto __NR_sendto
 #define SYS_set_mempolicy __NR_set_mempolicy
-#define SYS_set_robust_list __NR_set_robust_list
 #define SYS_set_thread_area __NR_set_thread_area
 #define SYS_set_tid_address __NR_set_tid_address
 #define SYS_setdomainname __NR_setdomainname
@@ -709,28 +679,22 @@
 #define SYS_shutdown __NR_shutdown
 #define SYS_sigaltstack __NR_sigaltstack
 #define SYS_signal __NR_signal
-#define SYS_signalfd __NR_signalfd
 #define SYS_sigpending __NR_sigpending
 #define SYS_sigprocmask __NR_sigprocmask
 #define SYS_socket __NR_socket
 #define SYS_socketpair __NR_socketpair
-#define SYS_splice __NR_splice
 #define SYS_ssetmask __NR_ssetmask
 #define SYS_stat __NR_stat
 #define SYS_stat64 __NR_stat64
 #define SYS_statfs __NR_statfs
-#define SYS_statfs64 __NR_statfs64
 #define SYS_stime __NR_stime
 #define SYS_swapoff __NR_swapoff
 #define SYS_swapon __NR_swapon
 #define SYS_symlink __NR_symlink
-#define SYS_symlinkat __NR_symlinkat
 #define SYS_sync __NR_sync
-#define SYS_sync_file_range __NR_sync_file_range
 #define SYS_sysfs __NR_sysfs
 #define SYS_sysinfo __NR_sysinfo
 #define SYS_syslog __NR_syslog
-#define SYS_tee __NR_tee
 #define SYS_tgkill __NR_tgkill
 #define SYS_time __NR_time
 #define SYS_timer_create __NR_timer_create
@@ -738,7 +702,6 @@
 #define SYS_timer_getoverrun __NR_timer_getoverrun
 #define SYS_timer_gettime __NR_timer_gettime
 #define SYS_timer_settime __NR_timer_settime
-#define SYS_timerfd __NR_timerfd
 #define SYS_times __NR_times
 #define SYS_tkill __NR_tkill
 #define SYS_truncate __NR_truncate
@@ -747,16 +710,11 @@
 #define SYS_umount2 __NR_umount2
 #define SYS_uname __NR_uname
 #define SYS_unlink __NR_unlink
-#define SYS_unlinkat __NR_unlinkat
-#define SYS_unshare __NR_unshare
 #define SYS_uselib __NR_uselib
 #define SYS_ustat __NR_ustat
 #define SYS_utime __NR_utime
-#define SYS_utimensat __NR_utimensat
 #define SYS_vfork __NR_vfork
 #define SYS_vhangup __NR_vhangup
-#define SYS_vmsplice __NR_vmsplice
-#define SYS_vserver __NR_vserver
 #define SYS_wait4 __NR_wait4
 #define SYS_waitid __NR_waitid
 #define SYS_waitpid __NR_waitpid
